@@ -87,6 +87,7 @@ enum WHICHCTCP_RETURN_VALUES {
 	OER_WHICHCTCP_ACTION = 1,
 	OER_WHICHCTCP_FINGER,
 	OER_WHICHCTCP_PING,
+	OER_WHICHCTCP_USERINFO,
 	OER_WHICHCTCP_VERSION,
 	OER_WHICHCTCP_INVALID
 };
@@ -257,6 +258,7 @@ enum OER_DEBUG_LEVELS {
 #define OER_BANVARS_NORMAL_BAN 3600
 #define OER_SAVE_INTERVAL 3600
 #define OER_ALLOWED_QUOTE_TIME_USEC 600000
+#define Q_NICK "Q"
 /* Define if you want to show server idle percentage */
 /* #undef OER_UPTIME_SHOW_IDLE */
 #define PUBMSG_FLOOD_LINES OER_PUBMSGS / 2
@@ -287,7 +289,7 @@ enum OER_DEBUG_LEVELS {
 #define OER_HELP "For a complete command reference go to http://oer.equnet.org/help.html"
 #define DEFAULT_NICKBK_MESSAGE "prohibited nick"
 #define OER_REALNAME "http://oer.equnet.org/help.html"
-#define OER_COPYRIGHT1 "oer version 1.0-27, Copyright (C) 2000 EQU <equ@equnet.org>"
+#define OER_COPYRIGHT1 "oer version 1.0-28, Copyright (C) 2000 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
