@@ -102,6 +102,10 @@ void parseirc(char *serveroutput)
 	if(!strcasecmp(command, "221")) {
 		return;
 	}
+	if(!strcasecmp(command, "250")) {
+		/* efnet local clients */
+		return;
+	}
 	if(!strcasecmp(command, "251")) {
 		return;
 	}
@@ -381,6 +385,9 @@ void parseirc(char *serveroutput)
 		if(amiop(channel) && !kicked && haschanflags(channel, "v") && hasuserflags(channel, host, "v")) {
 			addnewmm(channel, mystate->now,  "+v", nick);
 		}
+		if(amiop(channel) && !kicked && haschanflags(channel, "O") && isopa(host)) {
+			addnewmm(channel, mystate->now, "+o", nick);
+		}
 		if(amiop(channel) && !kicked && haschanflags(channel, "o") && isop(channel, host)) {
 			addnewmm(channel, mystate->now, "+o", nick);
 		}
@@ -521,7 +528,7 @@ void parseirc(char *serveroutput)
 			return;
 		}
 		if(isme(target)) {
-			oer_debug(OER_DEBUG_INFO, "parseirc(KICK)->i was kicked off %s by %s!%s\n", channel, nick, host);
+			oer_debug(OER_DEBUG_INFO, "parseirc(KICK)->I was kicked off %s by %s!%s\n", channel, nick, host);
 			initchannel(channel);
 			iwaskicked(channel);
 			return;
@@ -591,6 +598,10 @@ void parseirc(char *serveroutput)
 					continue;
 				}
 				if(haschanflags(channel, "u") && !isallowedop(channel, target)) {
+					if(isq(nick)) {
+						/* allow Q to set +o freely */
+						continue;
+					}
 					oer_debug(OER_DEBUG_INFO, "parseirc(MODE)->non-allowed op of nick %s on channel %s by %s!%s\n", target, channel, nick, host);
 					addnewmm(channel, mystate->now, "-o", target);
 				}
@@ -612,9 +623,13 @@ void parseirc(char *serveroutput)
 				snprintf(outstring, STRINGLEN, "%s!%s@%s", mystate->nick, mystate->user, mystate->host);
 				if(wild_match(target, outstring)) {
 					oer_debug(OER_DEBUG_INFO, "parseirc(MODE)->ban detected on me (%s)\n", target);
+					if(isq(nick)) {
+						/* allow Q to ban us */
+						continue;
+					}
 					if(amiop(channel) && haschanflags(channel, "b")) {
 						/* i am being banned, first kick then unban */
-						if(!isme(nick)) {
+						if(!isme(nick) && !isserver(nick)) {
 							snprintf(outstring, STRINGLEN, "KICK %s %s :do NOT ban %s, that's me!\n", channel, nick, target);
 							addnewtimed(mystate->now, OER_TIMED_IRC_COMMAND, OER_TIMED_IRC_COMMAND_DUMMY, outstring, NULL, NULL, NULL);
 						}
@@ -625,17 +640,28 @@ void parseirc(char *serveroutput)
 				break;
 			case OER_NTHMODE_UNBAN:
 				if(amiop(channel) && haschanflags(channel, "e") && ispermban(channel, target)) {
+					if(isq(nick)) {
+						/* allow Q to unban */
+						continue;
+					}
 					/* re-set the ban */
 					oer_debug(OER_DEBUG_INFO, "parseirc(MODE)->%s on channel %s tried to remove the permban %s\n", nick, channel, target);
 					addnewmm(channel, mystate->now, "+b", target);
-					snprintf(outstring, STRINGLEN, "do NOT remove %s ban from %s, it is in my permban list", target, channel);
-					sendreply(nick, 0, 3, 0, outstring);
+					if(!isserver(nick)) {
+						snprintf(outstring, STRINGLEN, "do NOT remove %s ban from %s, it is in my permban list", target, channel);
+						sendreply(nick, 0, 3, 0, outstring);
+
+					}
 				}
 				break;
 			}
 			if((deops > OER_MASSMODE_LIMIT) && (index(host, '@') != NULL) && !isme(nick)) {
 				oer_debug(OER_DEBUG_INFO, "parseirc(MODE)->mass modes detected on %s from %s\n", channel, nick);
-				if(amiop(channel) && haschanflags(channel, "m")) {
+				if(isq(nick)) {
+					/* allow Q to do massmodes */
+					continue;
+				}
+				if(amiop(channel) && haschanflags(channel, "m") && !isserver(nick)) {
 					addnewmm(channel, mystate->now, "-o", nick);
 					sendreply(nick, 0, 3, 0, "do NOT deop >3 users at a time");
 					deops = 0;
@@ -691,6 +717,10 @@ void parsemsg(char *nick, char *host, char *target, char *message)
 			oer_debug(OER_DEBUG_INFO, "parsemsg->isctcp = 1 and ctcp = PING\n");
 			parsectcp(nick, host, ctcp, message);
 			break;
+		case OER_WHICHCTCP_USERINFO:
+                        oer_debug(OER_DEBUG_INFO, "parsemsg->isctcp = 1 and ctcp = USERINFO\n");
+                        parsectcp(nick, host, ctcp, message);
+                        break;
 		case OER_WHICHCTCP_VERSION:
 			oer_debug(OER_DEBUG_INFO, "parsemsg->isctcp = 1 and ctcp = VERSION\n");
 			parsectcp(nick, host, ctcp, message);
